#!/usr/bin/env python
# -*- coding: UTF-8 -*-

#########################################################
# Appel des différents scripts pour ajouter un groupe
# licence GPL Eole
# Joël Cuissinat <joel.cuissinat@ac-dijon.fr>
#########################################################

###################
# modules importés
import sys
import getopt
import os
###################

#####################
# variables globales
tool_path="/usr/share/eole/backend"
# utilisation du dictionnaire
from creole import parsedico
dicoEole = parsedico.parse_dico()
serveur  = dicoEole["smb_netbios_name"]
dom      = dicoEole["domaine_messagerie_etab"]
#####################

def main():
    # gestion des options
    readonly=0
    partage=0
    donnees=0
    niveau=""
    liste=""
    mail=""
    domaine=""

    try:
        options, args = getopt.getopt(sys.argv[1:],'g:t:n:l:m:prdh',
        ['groupe=',
        'type=',
        'niveau=',
        'liste=',
        'mail=',
        'partage',
        'readonly',
        'donnees',
        'help'])
    
    except getopt.GetoptError:
        er_type, er_value, er_traceback = sys.exc_info()
        er_msg = str(er_value)
        sys.exit("l'option -%s est inconnue ou nécessite un argument" % er_msg[er_msg.index('-')+1])

    for (opt,val) in options:
        # nom du groupe
        if (opt == '-g') or (opt == '--groupe'):
            groupe = val.lower()
        # avec partage (lecture seule élève)
        if (opt == '-r') or (opt == '--readonly'):
            readonly = 1
        # avec partage (RW membres)
        if (opt == '-p') or (opt == '--partage'):
            partage = 1
        # avec partage (donnees/travail)
        if (opt == '-d') or (opt == '--donnees'):
            donnees = 1
        # avec liste (domaine restreint/internet)
        if (opt == '-l') or (opt == '--liste'):
            if val == "internet" or val == "principal":
                domaine = dom
            else :
                domaine = "i-"+dom
        # type du groupe
        if (opt == '-t') or (opt == '--type'):
            type = val
        # niveau associé à la classe
        if (opt == '-n') or (opt == '--niveau'):
            niveau = val
        # mail du propriétaire de la liste
        if (opt == '-m') or (opt == '--mail'):
            mail = val
        # et... l'aide 
        elif (opt == '-h') or (opt == '--help'):
            sys.exit("""options possibles :
                -g groupe
                -p (avec partage RW)
                -r (avec partage RO)
                -d (avec partage donnees/travail)
                -l domaine si liste (restreint|internet)
                -t type du groupe (Classe|Niveau|Matiere|Groupe|Equipe)
                -n niveau associé (si type=Classe)
                -m mail de l'admin (si liste)
                -h (aide)
                """)

    # definition des scripts
    script1="/usr/sbin/smbldap-groupadd"
    script2=tool_path+"/add-scribe-groupe.pl"
    script3=tool_path+"/synchro_file.py"
    script4="/usr/share/ead/create-list.pl"
    
    # definition de leurs paramètres
    para1 = "-a "
    para1+= groupe
    
    para2 = "-s "+serveur+" "
    para2+= "-t "+type+" "
    if partage == 1 or readonly == 1 or donnees == 1 :
        para2 += "-p "
    if niveau != "" :
        para2 += "-n "+niveau+" "
    if domaine != "" :
        para2 += "-m '%s@%s' " % (groupe,domaine)
    para2+= groupe
    
    para3 = ""
    
    if domaine != "" :
        para4 = "-m "+mail+" "
        para4+= "-t "+type+" "
        para4+= "-g "+groupe+" "
        para4+= "-d "+domaine
    
    #execution
    retour=os.system (script1+" "+para1)
    if retour != 0: 
        sys.exit("""Erreur d'ajout du groupe Samba""")
        
    retour=os.system (script2+" "+para2)
    if retour != 0: 
        sys.exit("""Erreur lors de la finalisation du groupe""")

    if domaine != "" :
        retour=os.system (script4+" "+para4)
        if retour != 0:
            sys.exit("""Problème lors de la création de liste""")

    # classe : on ajoute l'équipe pédago en plus
    if niveau != "" :
        script= tool_path+"/creation-groupe.py"
        para  = "-g profs-"+groupe+" -p -t Equipe -m "+mail+"-l "+domaine
        os.system (script+" "+para)
        # mise en place des répertoires 
        script= "/usr/share/ead/rep-classe.sh"
        para  = groupe
        os.system (script+" "+para)

    # une seule synchro si classe
    elif partage == 1 or readonly == 1 or donnees == 1:
        retour=os.system (script3+" "+para3)
        if retour != 0: 
            sys.exit("""Problème lors de la synchronisation""")
        # bricolage des ACL
        repertoire="/home/workgroups/"+groupe
        os.system("chmod 700 "+repertoire)
        if readonly == 1:
            os.system("setfacl -m g:professeurs:rwx "+repertoire)
            os.system("setfacl -m g:"+groupe+":r-x "+repertoire)
            os.system("getfacl --access --absolute-names "+repertoire+" | setfacl -d -M- "+repertoire)
        elif partage == 1:
            os.system("setfacl -m g:professeurs:rwx "+repertoire)
            os.system("setfacl -m g:"+groupe+":rwx "+repertoire)
            os.system("getfacl --access --absolute-names "+repertoire+" | setfacl -d -M- "+repertoire)
        elif donnees == 1:
            os.system("setfacl -m g:professeurs:r-x "+repertoire)            
            os.mkdir("%s/%s" % (repertoire,'donnees'))
            os.mkdir("%s/%s" % (repertoire,'travail'))
            os.system("setfacl -m g:%s:r-x %s/%s" % (groupe,repertoire,'donnees'))
            os.system("setfacl -m g:%s:rwx %s/%s" % ('professeurs',repertoire,'donnees'))
            os.system("setfacl -m g:%s:rwx %s/%s" % (groupe,repertoire,'travail'))
            os.system("setfacl -m g:%s:rwx %s/%s" % ('professeurs',repertoire,'travail'))
            os.system("getfacl --access --absolute-names %s/%s | setfacl -d -M- %s/%s" % (repertoire,'travail',repertoire,'travail'))
            os.system("getfacl --access --absolute-names %s/%s | setfacl -d -M- %s/%s" % (repertoire,'donnees',repertoire,'donnees'))
            print "donnees"
    
    formule="Le groupe "+groupe+" a été ajouté"
    sys.exit(formule)

if __name__ == "__main__":
    main()
